@@ -20,6 +20,7 @@
 //! The crate is split into:
 //! * A [`server`] module containing structs for use on the server.
 //! * A [`client`] module containing structs for use on the client.
+//! * A [`header_crypto`] module containing structs and traits for decrypting world packets.
 //! * An [`error`] module for errors that are shared by all modules.
 //! * A [`normalized_string`] module used for all modules to correctly handle strings.
 //!
@@ -45,29 +46,60 @@
 //!
 //! ```toml
 //! [dependencies]
-//! wow_srp = "0.2"
+//! wow_srp = { version = "0.3" }
 //! ```
 //!
 //! Then go to either the [`client`] module or [`server`] module for specific instructions.
 //!
+//! ## Features
+//!
+//! Two different arbitrary precision integer libraries can be used, either:
+//!
+//! * [num_bigint](https://crates.io/crates/num-bigint). A slow pure Rust implementation without
+//! external dependencies. This is enabled by default, and requires no opt in.
+//!
+//! * [rug](https://crates.io/crates/rug). A fast wrapper around the [GMP library](https://gmplib.org/)
+//! with external dependencies, as described in the [gmp_mpfr_sys documentation](https://docs.rs/gmp-mpfr-sys/1.4.6/gmp_mpfr_sys/index.html#building-on-gnulinux).
+//! This is enabled with the `rug` feature and disabling default features.
+//! So **instead** of the above do this:
+//!
+//! ```toml
+//! [dependencies]
+//! wow_srp = { version = "0.3", default-features = false, features = ["rug"] }
+//! ```
+//!
+//! The `rug` feature leads to a 50% decrease in total time. It is highly recommended to enable
+//! this feature for production usage since it also theoretically has better security.
+//!
+//! To see the performance difference on your setup you can run `cargo bench` for the default version,
+//! and `cargo bench --features rug --no-default-features` for the `rug` version.
+//!
 //! # Other implementations
 //!
 //! * [Ember](https://github.com/EmberEmu/Ember/tree/development/src/libs/srp6) is a C++ implementation for 1.12 with a clean, tested implementation of the protocol.
 //! * [ArcEmu](https://github.com/arcemu/arcemu/blob/00355000cac5d0b9bce42bf6d03d4aeda9e396ea/src/logon/Auth/AuthSocket.cpp#L74) is a C++ implementation for 3.3.5.
 //! * [vMangos](https://github.com/vmangos/core/blob/fa9351de7e832510309209351c17f5c53f3155ef/src/realmd/AuthSocket.cpp#L350) is a C++ implementation.
 //! * [WoWCore](https://github.com/RomanRom2/WoWCore/blob/92b7646c2bafb22ad6dca0acc9496a35561292c4/05875_1.12.1/pas/sandbox/AuthServer.pas#L133) is a Pascal implementation that has 1.12, 2.4.3 and 3.3.5 versions.
+//! * [Shadowburn](https://gitlab.com/shadowburn/shadowburn/-/blob/ac905fabf56579b3bda6f16689c74f544da043e2/apps/common/lib/accounts/accounts.ex#L88) is an Elixir implementation.
 //!
 //! [archive]: https://web.archive.org/web/20210620154707/https://wowdev.wiki/Login_Packet
 
-#![doc(html_root_url = "https://docs.rs/wow_srp/0.2.0")]
+#![doc(html_root_url = "https://docs.rs/wow_srp/0.3.0")]
 #![forbid(unsafe_code)]
 #![warn(
     clippy::perf,
     clippy::correctness,
     clippy::style,
     clippy::missing_const_for_fn,
+    clippy::missing_errors_doc,
+    clippy::missing_panics_doc,
+    clippy::doc_markdown,
+    clippy::unseparated_literal_suffix,
     missing_docs
 )]
+// There are false positives where we don't want to
+// take ownership of something unnecessarily.
+#![allow(clippy::needless_borrow)]
 
 pub use key::PublicKey;
 pub use key::PASSWORD_VERIFIER_LENGTH;
@@ -85,7 +117,6 @@ pub use primes::LARGE_SAFE_PRIME_LITTLE_ENDIAN;
 pub(crate) mod bigint;
 pub mod client;
 pub mod error;
-#[allow(missing_docs)]
 pub mod header_crypto;
 mod key;
 pub mod normalized_string;
