@@ -24,10 +24,10 @@ const PRECALCULATED_XOR_HASH: [u8; SHA1_HASH_LENGTH as usize] = [
     221, 123, 176, 58, 56, 172, 115, 17, 3, 152, 124, 90, 80, 111, 202, 150, 108, 123, 194, 167,
 ];
 
-/// Calculate the `x` value which is used for generating the password verifier `v`. See [calculate_password_verifier].
+/// Calculate the `x` value which is used for generating the password verifier `v`. See [`calculate_password_verifier`].
 ///
 /// `x` is calculated as `H( salt | H( upper( username | : |  password ) ) )` as described on page 3 of [RFC2945] and page 8 of [RFC5054].
-/// Uppercasing is not a requirement for SRP6 itself, only for the WoW client.
+/// Uppercasing is not a requirement for SRP6 itself, only for the `WoW` client.
 ///
 /// `H()` is the SHA1 hashing function.
 /// `:` is the literal character `:`.
@@ -153,19 +153,19 @@ pub fn calculate_S(
 pub fn calculate_interleaved(S: &SKey) -> SessionKey {
     let S = S.to_equal_slice();
 
-    let mut E = [0u8; (S_LENGTH / 2) as usize];
+    let mut E = [0_u8; (S_LENGTH / 2) as usize];
     for (i, e) in S.iter().step_by(2).enumerate() {
         E[i] = *e;
     }
     let G = Sha1::new().chain(&E[..S.len() / 2]).finalize();
 
-    let mut F = [0u8; (S_LENGTH / 2) as usize];
+    let mut F = [0_u8; (S_LENGTH / 2) as usize];
     for (i, f) in S.iter().skip(1).step_by(2).enumerate() {
         F[i] = *f;
     }
     let H = Sha1::new().chain(&F[..S.len() / 2]).finalize();
 
-    let mut result = [0u8; SESSION_KEY_LENGTH as usize];
+    let mut result = [0_u8; SESSION_KEY_LENGTH as usize];
     let zip = G.iter().zip(H.iter());
     for (i, r) in zip.enumerate() {
         result[i * 2] = *r.0;
@@ -216,7 +216,7 @@ pub(crate) fn calculate_xor_hash(
 
     let g_hash = Sha1::new().chain([generator.as_u8()]).finalize();
 
-    let mut xor_hash = [0u8; SHA1_HASH_LENGTH as usize];
+    let mut xor_hash = [0_u8; SHA1_HASH_LENGTH as usize];
     for (i, n) in large_safe_prime_hash.iter().enumerate() {
         xor_hash[i] = *n as u8 ^ g_hash[i];
     }
@@ -262,6 +262,24 @@ pub fn calculate_reconnect_proof(
     Proof::from_le_bytes(s.into())
 }
 
+pub fn calculate_world_server_proof(
+    username: &NormalizedString,
+    session_key: &SessionKey,
+    server_seed: u32,
+    client_seed: u32,
+) -> Proof {
+    let server_proof: [u8; PROOF_LENGTH as usize] = Sha1::new()
+        .chain(&username.as_ref())
+        .chain(0_u32.to_le_bytes())
+        .chain(client_seed.to_le_bytes())
+        .chain(server_seed.to_le_bytes())
+        .chain(&session_key.as_le())
+        .finalize()
+        .into();
+
+    Proof::from_le_bytes(server_proof)
+}
+
 #[cfg(test)]
 mod test {
     use crate::primes::{
@@ -277,10 +295,50 @@ mod test {
         use crate::srp_internal::{
             calculate_S, calculate_client_proof, calculate_interleaved,
             calculate_password_verifier, calculate_reconnect_proof, calculate_server_proof,
-            calculate_server_public_key, calculate_session_key, calculate_u, calculate_x,
+            calculate_server_public_key, calculate_session_key, calculate_u,
+            calculate_world_server_proof, calculate_x,
         };
+        use std::convert::TryInto;
         use std::fs::read_to_string;
 
+        #[test]
+        fn verify_world_server_proof() {
+            const FILENAME: &str = "tests/srp6_internal/calculate_world_server_proof.txt";
+
+            let contents = read_to_string(FILENAME).unwrap();
+            for line in contents.lines() {
+                let mut line = line.split_whitespace();
+
+                let username = NormalizedString::new(line.next().unwrap()).unwrap();
+
+                let session_key = SessionKey::from_le_hex_str(line.next().unwrap());
+
+                let server_seed = u32::from_le_bytes(
+                    hex::decode(line.next().unwrap())
+                        .unwrap()
+                        .try_into()
+                        .unwrap(),
+                );
+                let client_seed = u32::from_le_bytes(
+                    hex::decode(line.next().unwrap())
+                        .unwrap()
+                        .try_into()
+                        .unwrap(),
+                );
+
+                let expected = Proof::from_le_hex_str(line.next().unwrap());
+
+                let result = calculate_world_server_proof(
+                    &NormalizedString::new(&username.to_string()).unwrap(),
+                    &session_key,
+                    server_seed,
+                    client_seed,
+                );
+
+                assert_eq!(result, expected);
+            }
+        }
+
         #[test]
         fn verify_reconnection_proof() {
             let contents =
